@@ -7,18 +7,19 @@ head(ukLang)
 
 ## ----message=FALSE-------------------------------------------------------
 library(tidyr)
-library(magrittr)
 
-ukLang %<>% gather(key, value, -Ability)
+ukLang <- gather(ukLang, key, value, -Ability)
 
 ## ------------------------------------------------------------------------
-ukLang %>% separate(key, into = c("region", "language", "statistic"), sep = " >> ") %>% head
+ukLang <- separate(ukLang, key, into = c("region", "language", "statistic"), sep = " >> ")
+head(ukLang)
 
 ## ------------------------------------------------------------------------
 url <- "http://en.wikipedia.org/wiki/New_Zealand_general_election,_2002"
 xp <- "//caption[starts-with(text(), 'Electorate results')]/ancestor::table"
+body_xp <- "//tr[./td[not(@colspan = '10')]]"
 
-nz1 <- htmltab(doc = url, which = xp, encoding = "UTF-8")
+nz1 <- htmltab(doc = url, which = xp, body = body_xp, encoding = "UTF-8")
 head(nz1)
 
 ## ------------------------------------------------------------------------
